pub trait Read {
// Required method
fn read(&self, buf: &mut [u8], offset: usize) -> Result<usize, Error>;
}Expand description
To make a lazy reader cursor from scratch, this trait must be implemented.
See Cursor::new about how to create a cursor based on this trait.